==> cook.1.7.tar.gz: cook.1.7/cook/os.h <==
/*
 *	cook - file construction tool
 *	Copyright (C) 1990, 1991, 1992, 1993, 1994 Peter Miller.
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * MANIFEST: interface definition for cook/os.c
 */

#ifndef OS_H
#define OS_H

#include <ac/time.h>
#include <str.h>
#include <word.h>

time_t os_mtime_oldest _((string_ty *));
time_t os_mtime_newest _((string_ty *));
int os_mtime_adjust _((string_ty *, time_t));
int os_touch _((string_ty *));
int os_execute _((wlist *cmd, string_ty *input, int errok));
int os_exists _((string_ty *));
string_ty *os_accdir _((void));
string_ty *os_curdir _((void));
string_ty *os_dirname _((string_ty *));
string_ty *os_entryname _((string_ty *));
string_ty *os_pathname _((string_ty *));
int os_legal_path _((string_ty *));
int os_delete _((string_ty *));
void os_meter_begin _((void));
void os_meter_end _((void));
char *signal_name _((int));
int os_clear_stat _((string_ty *));
int exit_status _((char *cmd, int status, int errok));

#endif /* OS_H */

==> cook_2.5.orig.tar.gz: cook-2.5.orig/cook/os.h <==
/*
 *	cook - file construction tool
 *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995, 1997, 1998 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for cook/os.c
 */

#ifndef OS_H
#define OS_H

#include <ac/time.h>
#include <str.h>
#include <str_list.h>

time_t os_mtime_oldest _((string_ty *));
time_t os_mtime_newest _((string_ty *));
int os_mtime_adjust _((string_ty *, time_t));
int os_touch _((string_ty *));
int os_execute _((string_list_ty *cmd, string_ty *input, int errok));
int os_exists _((string_ty *));
int os_exists_symlink _((string_ty *));
string_ty *os_accdir _((void));
string_ty *os_curdir _((void));
string_ty *os_dirname _((string_ty *));
string_ty *os_entryname _((string_ty *));
string_ty *os_pathname _((string_ty *));
int os_legal_path _((string_ty *));
int os_delete _((string_ty *path, int echo));
int os_clear_stat _((string_ty *));
int exit_status _((char *cmd, int status, int errok));
int os_mkdir _((string_ty *path, int echo));

#endif /* OS_H */
